==> django-froala-editor-1.2.3.tar.gz: django-froala-editor-1.2.3/froala_editor/static/froala_editor/js/langs/sr.js <==
/*!
 * froala_editor v1.2.3 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Serbian.
 */

$.Editable.LANGS['sr'] = {
  translation: {
    "Bold": "Podebljan",
    "Italic": "Isko\u0161en",
    "Underline": "Podvu\u010deno",
    "Strikethrough": "Precrtan",
    "Font Size": "Veli\u010dina fontova",
    "Color": "Boja",
    "Background": "Pozadine",
    "Text": "Tekst",
    "Format Block": "Formatiranje bloka",
    "Normal": "Normalno",
    "Paragraph": "Paragraf",
    "Code": "Izvorni kod",
    "Quote": "Citat",
    "Heading 1": "Zaglavlje 1",
    "Heading 2": "Zaglavlje 2",
    "Heading 3": "Zaglavlje 3",
    "Heading 4": "Zaglavlje 4",
    "Heading 5": "Zaglavlje 5",
    "Heading 6": "Zaglavlje 6",
    "Block Style": "Blok style",
    "Alignment": "Poravnano",
    "Align Left": "Poravnano levo",
    "Align Center": "Poravnano centar",
    "Align Right": "Poravnano desno",
    "Justify": "Cjelokupno poravnanje",
    "Numbered List": "Numerisana lista",
    "Bulleted List": "Lista nabrajanja",
    "Indent Less": "Uvuci paragraf",
    "Indent More": "Izvuci paragraf",
    "Select All": "Obele\u017ei sve",
    "Insert Link": "Ubaci vezu",
    "Insert Image": "Ubaci sliku",
    "Insert Video": "Ubaci video",
    "Undo": "Nazad",
    "Redo": "Napred",
    "Show HTML": "Prika\u017ei HTML kod",
    "Float Left": "Prebaci levo",
    "Float None": "Bez prebacivanja",
    "Float Right": "Prebaci desno",
    "Replace Image": "Zameni sliku",
    "Remove Image": "Ukloni sliku",
    "Title": "Naslov",
    "Drop image": "Izbaci sliku",
    "or click": "ili odaberi",
    "or": "ili",
    "Enter URL": "Enter URL",
    "Please wait!": "Molim sa\u010dekaj.",
    "Are you sure? Image will be deleted.": "Da li ste sigurni da \u017eelite da obri\u0161ete ovu sliku?",
    "UNLINK": "Ukloni link",
    "Open in new tab": "Otvori u novom prozoru",
    "Type something": "Ukucajte ne\u0161tp",
    "Cancel": "Opozovi",
    "OK": "Ok",
    "Manage images": "Upravljanje sliku",
    "Delete": "Obri\u0161i",
    "Font Family": "Odaberi font",
    "Insert Horizontal Line": "Ubaci horizontalna liniju",
    "Table": "Tabela",
    "Insert table": "Ubaci tabelu",
    "Cell": "\u0106elija",
    "Row": "Red",
    "Column": "Kolona",
    "Delete table": "Obri\u0161i tabelu",
    "Insert cell before": "Ubaci \u0107elije pre",
    "Insert cell after": "Ubaci \u0107elije posle",
    "Delete cell": "Obri\u0161i polje",
    "Merge cells": "Spoji \u0107elije",
    "Horizontal split": "Horizontalno razdvajanje polja",
    "Vertical split": "Vertikalno razdvajanje polja",
    "Insert row above": "Ubaci red iznad",
    "Insert row below": "Ubaci red ispod",
    "Delete row": "Obri\u0161i red",
    "Insert column before": "Ubaci kolonu pre",
    "Insert column after": "Ubaci kolonu posle",
    "Delete column": "Obri\u0161i kolonu"
  },
  direction: "ltr"
};

==> django-froala-editor-1.2.4.tar.gz: django-froala-editor-1.2.4/froala_editor/static/froala_editor/js/langs/sr.js <==
/*!
 * froala_editor v1.2.4 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Serbian.
 */

$.Editable.LANGS['sr'] = {
  translation: {
    "Bold": "Podebljan",
    "Italic": "Isko\u0161en",
    "Underline": "Podvu\u010deno",
    "Strikethrough": "Precrtan",
    "Font Size": "Veli\u010dina fontova",
    "Color": "Boja",
    "Background": "Pozadina",
    "Text": "Tekst",
    "Format Block": "Formatiranje bloka",
    "Normal": "normalan",
    "Paragraph": "Stav",
    "Code": "Izvorni kod",
    "Quote": "Citat",
    "Heading 1": "Naslov 1",
    "Heading 2": "Naslov 2",
    "Heading 3": "Naslov 3",
    "Heading 4": "Naslov 4",
    "Heading 5": "Naslov 5",
    "Heading 6": "Naslov 6",
    "Block Style": "Blok stil",
    "Alignment": "Postrojavanje",
    "Align Left": "Poravnano levo",
    "Align Center": "Poravnano centar",
    "Align Right": "Poravnano desno",
    "Justify": "Cjelokupno poravnanje",
    "Numbered List": "Numerisana lista",
    "Bulleted List": "Lista nabrajanja",
    "Indent Less": "Uvuci paragraf",
    "Indent More": "Izvuci paragraf",
    "Select All": "Obele\u017ei sve",
    "Insert Link": "Ubaci vezu",
    "Insert Image": "Ubaci sliku",
    "Insert Video": "Ubaci video",
    "Undo": "Rasplesti",
    "Redo": "Napred",
    "Show HTML": "Prika\u017ei HTML kod",
    "Float Left": "Prebaci levo",
    "Float None": "Bez prebacivanja",
    "Float Right": "Prebaci desno",
    "Replace Image": "Zameni sliku",
    "Remove Image": "Ukloni sliku",
    "Title": "Naslov",
    "Drop image": "Izbaci sliku",
    "or click": "ili odaberi",
    "or": "ili",
    "Enter URL": "Enter URL",
    "Please wait!": "Molimo sa\u010dekajte !",
    "Are you sure? Image will be deleted.": "Da li ste sigurni da \u017eelite da obri\u0161ete ovu sliku?",
    "UNLINK": "Ukloni link",
    "Open in new tab": "Otvori u novom prozoru",
    "Type something": "Ukucajte ne\u0161tp",
    "Cancel": "Otkazati",
    "OK": "Ok",
    "Manage images": "Upravljanje sliku",
    "Delete": "Izbrisati",
    "Font Family": "Odaberi font",
    "Insert Horizontal Line": "Ubaci horizontalna liniju",
    "Table": "Tabela",
    "Insert table": "Ubaci tabelu",
    "Cell": "\u0106elija",
    "Row": "Red",
    "Column": "Kolona",
    "Delete table": "Izbrisati tabelu",
    "Insert cell before": "Ubaci \u0107elije pre",
    "Insert cell after": "Ubaci \u0107elije posle",
    "Delete cell": "Izbrisati polje",
    "Merge cells": "Spoji \u0107elije",
    "Horizontal split": "Horizontalno razdvajanje polja",
    "Vertical split": "Vertikalno razdvajanje polja",
    "Insert row above": "Ubaci red iznad",
    "Insert row below": "Ubaci red ispod",
    "Delete row": "Izbrisati red",
    "Insert column before": "Ubaci kolonu pre",
    "Insert column after": "Ubaci kolonu posle",
    "Delete column": "Izbrisati kolonu",
    "Uploading image": "Postaviti slika",
    "Upload File": "Postaviti fajl",
    "Drop File": "Drop fajl",
    "Clear formatting": "Brisanje formatiranje"
  },
  direction: "ltr"
};
